@@ -1,7 +1,8 @@
 """ Generic GraphQL Helpers """
 from abc import ABC
 from datetime import datetime
-from typing import Any, Dict, List, Tuple, Type, Union, get_type_hints
+from inspect import isclass
+from typing import Any, Dict, List, Tuple, Type, Union, cast, get_type_hints
 
 from mcli.api.typing_future import get_args, get_origin  # type: ignore - unknown import symbol
 
@@ -37,6 +38,7 @@ class DeserializableModel(ABC):
             Returns the deserialized value of the field for the given dataclass
             object
         """
+
         type_hints = get_type_hints(cls)
         if field in type_hints:
             found_type: Type[Any] = type_hints[field]
@@ -45,14 +47,40 @@ class DeserializableModel(ABC):
                 # Unwrap optional type
                 type_args: Tuple[Type[Any]] = get_args(found_type)  # type: ignore
                 found_type = type_args[0]
-            if found_type is DeserializableModel:
-                assert isinstance(found_type, DeserializableModel)
-                new_properties = found_type.translate_properties(properties=value)
-                return DeserializableModel(**new_properties)
-            elif found_type is datetime:
+
+            found_type_origin = get_origin(found_type)
+            if isclass(found_type) and issubclass(found_type, datetime):
                 if isinstance(value, str):
-                    value = int(value)
-                return datetime.fromtimestamp(value / 1000.0)
+                    # Convert from the postgres string to something python-compatible
+                    value = value.replace('Z', '+00:00')
+                    value = datetime.fromisoformat(value)
+                return value
+            elif found_type_origin == list:
+                type_list = get_args(found_type)
+                type_list = cast(List[Type[Any]], type_list)
+                assert len(type_list) > 0
+                iterable_type: Type[Any] = type_list[0]
+                if isclass(iterable_type) and issubclass(iterable_type, DeserializableModel):
+                    return [iterable_type(**iterable_type.translate_properties(properties=v)) for v in value]
+
+                # TODO: I'm pretty sure a bug was introduced in this case
+                #       future self, pls look into in future
+                return found_type_origin(value)  # type: ignore
+
+            elif found_type_origin == dict:
+                assert isinstance(value, dict)
+                type_list = get_args(found_type)
+                type_list = cast(List[Type[Any]], type_list)
+                assert len(type_list) > 1
+                value_type: Type[Any] = type_list[1]
+                for k, v in value.items():
+                    if isclass(found_type) and issubclass(value_type, DeserializableModel):
+                        v = value_type(**value_type.translate_properties(properties=v))
+                    value[k] = v
+                return value
+            elif isclass(found_type) and issubclass(found_type, DeserializableModel):
+                new_properties = found_type.translate_properties(properties=value)
+                return found_type(**new_properties)
             else:
                 return found_type(value)
 
