@@ -110,7 +110,7 @@ class MCLIRunDisplay(MCLIGetDisplay):
             user_instances = UserInstanceRegistry()
             options = user_instances.lookup(request)
             num_gpu_types = len(set([x.gpu_type for x in options if GPUType.from_string(x.gpu_type) != GPUType.NONE]))
-            if num_gpu_types == 1:
+            if num_gpu_types <= 1:
                 self.use_compact_view = True
 
     @property
