@@ -9,7 +9,8 @@ from kubernetes import client
 from mcli.config import MESSAGE, MCLIConfig, MCLIConfigError
 from mcli.models.mcli_platform import MCLIPlatform
 from mcli.utils.utils_epilog import CommonLog, ContextPodStatus, EpilogSpinner, RunEpilog
-from mcli.utils.utils_kube import deserialize, find_pods_by_label, get_job_num_pods, read_pod_logs, stream_pod_logs
+from mcli.utils.utils_kube import (PlatformRun, delete_runs, deserialize, find_pods_by_label, get_job_num_pods,
+                                   read_pod_logs, stream_pod_logs)
 from mcli.utils.utils_kube_labels import label
 from mcli.utils.utils_logging import FAIL, INFO, console
 from mcli.utils.utils_pod_state import PodState
@@ -100,7 +101,12 @@ def get_logs(
                 return 0
             elif status.state == PodState.FAILED_PULL:
                 # Pod failed at image pull so no logs present
-                CommonLog(logger).log_pod_failed_pull(run_name, pod.containers[0].image)
+                pod_spec = cast(client.V1PodSpec, pod.spec)
+                container = cast(List[client.V1Container], pod_spec.containers)[0]
+                image = cast(str, container.image)
+                CommonLog(logger).log_pod_failed_pull(run_name, image)
+                with console.status('Deleting failed run...'):
+                    delete_runs([PlatformRun(run_name, platform.to_kube_context())])
                 return 1
             elif status.state.before(PodState.QUEUED, inclusive=True):
                 # Pod still waiting to be scheduled. Return
