@@ -61,8 +61,8 @@ def run_entrypoint(
 
     if tail:
         with MCLIPlatform.use(mcli_job.platform.mcli_platform) as platform:
-            logger.info(f'{INFO} Run {mcli_job.unique_name} submitted. Waiting for it to start...')
-            logger.info(f'{INFO} Press Ctrl+C to quit and follow your run manually.')
+            logger.info(f'{INFO} Run [cyan]{mcli_job.unique_name}[/] submitted. Waiting for it to start...')
+            logger.info(f'{INFO} You can press Ctrl+C to quit and follow your run manually.')
             epilog = RunEpilog(mcli_job.unique_name, platform.namespace)
             last_status: Optional[PodStatus] = None
             with EpilogSpinner() as spinner:
@@ -86,7 +86,7 @@ def run_entrypoint(
                 logger.debug(last_status)
                 return 1
 
-            logger.info(f'{OK} Run {mcli_job.unique_name} started')
+            logger.info(f'{OK} Run [cyan]{mcli_job.unique_name}[/] started')
             logger.info(f'{INFO} Following run logs. Press Ctrl+C to quit.\n')
             for line in stream_pod_logs(epilog.rank0_pod, platform.namespace):
                 print(line)
